@@ -2,9 +2,6 @@
 #include <stdio.h>
 #include <math.h>
 
-/* temporary for aarch64 */
-void _set_tls(void) {}
-
 int main(void)
 {
 	char foo[50];
